@@ -29,7 +29,7 @@ from .clnsig import CLINSIG_MAP, REV_CLINSIG_MAP, TRUSTED_REVSTAT_LEVEL
 from .file_types import FILE_TYPE_MAP
 from .filters import CLINICAL_FILTER_BASE, CLINICAL_FILTER_BASE_CANCER, CLINICAL_FILTER_BASE_SV
 from .gene_tags import (
-    GENE_CUSTOM_INHERITANCE_MODELS,
+    GENE_PANELS_INHERITANCE_MODELS,
     INCOMPLETE_PENETRANCE_MAP,
     MODELS_MAP,
     PANEL_GENE_INFO_MODELS,
