@@ -307,9 +307,6 @@ def populate_case_filter_form(params):
     """
     form = CaseFilterForm(params)
     form.search_type.default = params.get("search_type")
-    search_term = form.search_term.data or ""
-    if ":" in search_term:
-        form.search_term.data = search_term[search_term.index(":") + 1 :]  # remove prefix
     return form
 
 
@@ -375,7 +372,7 @@ def get_sanger_unevaluated(store, institute_id, user_id):
     return unevaluated
 
 
-def gene_variants(store, pymongo_cursor, variant_count, institute_id, page=1, per_page=50):
+def gene_variants(store, pymongo_cursor, variant_count, page=1, per_page=50):
     """Pre-process list of variants."""
 
     skip_count = per_page * max(page - 1, 0)
