@@ -109,10 +109,12 @@ class GeneVariantFiltersForm(FlaskForm):
     """Base FiltersForm for SNVs"""
 
     variant_type = SelectMultipleField(choices=[("clinical", "clinical"), ("research", "research")])
-    hgnc_symbols = TagListField("HGNC Symbols/Ids (case sensitive)")
+    hgnc_symbols = TagListField(
+        "HGNC Symbols (comma-separated, case sensitive)", validators=[validators.InputRequired()]
+    )
     filter_variants = SubmitField(label="Filter variants")
     rank_score = IntegerField(default=15)
-    phenotype_terms = TagListField("HPO terms")
+    phenotype_terms = TagListField("HPO terms (comma-separated)")
     phenotype_groups = TagListField("Phenotype groups")
     similar_case = TagListField("Phenotypically similar case")
     cohorts = TagListField("Cohorts")
