@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
 import datetime
+import json
 import logging
 
-from flask import Blueprint, abort, flash, redirect, render_template, request, url_for
+from flask import Blueprint, Response, flash, redirect, render_template, request, url_for
 from flask_login import current_user
 from flask_weasyprint import HTML, render_pdf
 
 from scout.server.extensions import store
-from scout.server.utils import templated, user_institutes
+from scout.server.utils import jsonconverter, public_endpoint, templated, user_institutes
 
 from . import controllers
 from .forms import PanelGeneForm
@@ -16,12 +17,24 @@ LOG = logging.getLogger(__name__)
 panels_bp = Blueprint("panels", __name__, template_folder="templates")
 
 
+@panels_bp.route("/api/v1/panels/<panel_name>", methods=["GET", "POST"])
+@public_endpoint
+def api_panels(panel_name):
+    """Return JSON data about panels with a given panel name.
+    Returns all versions.
+    """
+    json_out = controllers.get_panels(store, panel_name)
+
+    return Response(json.dumps(json_out, default=jsonconverter), mimetype="application/json")
+
+
 @panels_bp.route("/panels", methods=["GET", "POST"])
 @templated("panels/panels.html")
 def panels():
     """Show all panels for a user"""
-    if request.method == "POST":
-        controllers.panel_create_or_update(store, request)
+    if request.method == "POST":  # Edit/create a new panel and redirect to its page
+        redirect_panel_id = controllers.panel_create_or_update(store, request)
+        return redirect(url_for("panels.panel", panel_id=redirect_panel_id))
 
     institutes = list(user_institutes(store, current_user))
     panel_names = [
@@ -59,6 +72,7 @@ def panels():
 @templated("panels/panel.html")
 def panel(panel_id):
     """Display (and add pending updates to) a specific gene panel."""
+
     panel_obj = store.gene_panel(panel_id) or store.panel(panel_id)
 
     if request.method == "POST":
@@ -235,7 +249,6 @@ def tx_choices(hgnc_id, panel_obj):
 @templated("panels/gene-edit.html")
 def gene_edit(panel_id, hgnc_id):
     """Edit additional information about a panel gene."""
-
     panel_obj = store.panel(panel_id)
     hgnc_gene = store.hgnc_gene(hgnc_identifier=hgnc_id, build="37") or store.hgnc_gene(
         hgnc_identifier=hgnc_id, build="38"
@@ -254,14 +267,17 @@ def gene_edit(panel_id, hgnc_id):
             info_data["custom_inheritance_models"] = info_data["custom_inheritance_models"].split(
                 ","
             )
-
         store.add_pending(panel_obj, hgnc_gene, action=action, info=info_data)
         return redirect(url_for(".panel", panel_id=panel_id))
 
     if panel_gene:
-        form.custom_inheritance_models.data = ", ".join(
-            panel_gene.get("custom_inheritance_models", [])
-        )
+        custom_models = [
+            model for model in panel_gene.get("custom_inheritance_models", []) if model != ""
+        ]
+        if custom_models:
+            form.custom_inheritance_models.data = ", ".join(
+                panel_gene.get("custom_inheritance_models")
+            )
         for field_key in [
             "disease_associated_transcripts",
             "reduced_penetrance",
