@@ -21,6 +21,25 @@ MAIL_USE_SSL = False
 # If null no badge is displayed in scout
 ACCREDITATION_BADGE = "swedac-1926-iso17025.png"
 
+# LDAP login Settings
+# Complete list of accepted parameters available here: https://github.com/rroemhild/flask-ldapconn
+# LDAP_HOST = "localhost" # Can also be named LDAP_SERVER
+# LDAP_PORT = 389
+# LDAP_BASE_DN = 'cn=admin,dc=example,dc=com # Can also be named LDAP_BINDDN
+# LDAP_USER_LOGIN_ATTR = "mail" # Can also be named LDAP_SEARCH_ATTR
+# LDAP_USE_SSL = False
+# LDAP_USE_TLS = True
+
+# Parameters required for Google Oauth 2.0 login
+# GOOGLE = dict(
+#    client_id="client.apps.googleusercontent.com",
+#    client_secret="secret",
+#    discovery_url="https://accounts.google.com/.well-known/openid-configuration",
+# )
+
+# Chanjo database connection string - used by chanjo report to create coverage reports
+# SQLALCHEMY_DATABASE_URI = "mysql+pymysql://test_user:test_passwordw@127.0.0.1:3306/chanjo"
+
 # Configure gens service
 # GENS_HOST = "127.0.0.1"
 # GENS_PORT = 5000
@@ -48,6 +67,7 @@ ACCREDITATION_BADGE = "swedac-1926-iso17025.png"
 #    "default" : {"binary_path": "/miniconda3/envs/loqus2.5/bin/loqusdb", "config_path": "/home/user/settings/loqus_default.yaml"},
 #    "loqus_api" : {"api_url": "http://127.0.0.1:9000"},
 # }
+
 #
 # Cloud IGV tracks can be configured here to allow users to enable them on their IGV views.
 # CLOUD_IGV_TRACKS = [
@@ -71,16 +91,21 @@ ACCREDITATION_BADGE = "swedac-1926-iso17025.png"
 REPORT_LANGUAGE = "en"
 ACCEPT_LANGUAGES = ["en", "sv"]
 
+# TICKET_SYSTEM_EMAIL = "support@test_service.com"
+
 # FEATURE FLAGS
 SHOW_CAUSATIVES = True
 SHOW_OBSERVED_VARIANT_ARCHIVE = True
-HIDE_ALAMUT_LINK = False
+HIDE_ALAMUT_LINK = True
 
 # OMIM API KEY: Required for downloading definitions from OMIM (https://www.omim.org/api)
 # OMIM_API_KEY = 'valid_omim_api_key'
 
-# Rank model links
+# Parameters for enabling Phenomizer queries
+# PHENOMIZER_USERNAME = "test_user"
+# PHENOMIZER_PASSWORD = "test_password"
 
+# Rank model links
 RANK_MODEL_LINK_PREFIX = "https://github.com/Clinical-Genomics/reference-files/blob/master/rare-disease/rank_model/rank_model_-v"
 RANK_MODEL_LINK_POSTFIX = "-.ini"
 SV_RANK_MODEL_LINK_PREFIX = "https://github.com/Clinical-Genomics/reference-files/blob/master/rare-disease/rank_model/svrank_model_-v"
