@@ -73,11 +73,12 @@ def get_request_json(url, headers=None):
     return json_response
 
 
-def delete_request_json(url, headers=None):
+def delete_request_json(url, headers=None, data=None):
     """Send a DELETE request to a remote API and return its response
     Args:
         url(str): url to send request to
         headers(dict): eventual request HEADERS to use in request
+        data(dict): eventual request data to ba passed as a json object
     Returns:
         json_response(dict)
     """
@@ -85,7 +86,9 @@ def delete_request_json(url, headers=None):
     json_response = {}
     try:
         LOG.debug(f"Sending DELETE request to {url}")
-        if headers:
+        if headers and data:
+            resp = requests.delete(url, headers=headers, json=data)
+        elif headers:
             resp = requests.delete(url, headers=headers)
         else:
             resp = requests.delete(url)
